@@ -1,6 +1,7 @@
 use rustdoc_types::Crate;
 use std::rc::Rc;
 
+use crate::Options;
 use crate::PublicItem;
 
 mod item_iterator;
@@ -9,8 +10,11 @@ use item_iterator::ItemIterator;
 mod intermediate_public_item;
 use intermediate_public_item::IntermediatePublicItem;
 
-pub fn public_items_in_crate(crate_: &Crate) -> impl Iterator<Item = crate::PublicItem> + '_ {
-    ItemIterator::new(crate_).map(|p| intermediate_public_item_to_public_item(&p))
+pub fn public_items_in_crate(
+    crate_: &Crate,
+    options: Options,
+) -> impl Iterator<Item = crate::PublicItem> + '_ {
+    ItemIterator::new(crate_, options).map(|p| intermediate_public_item_to_public_item(&p))
 }
 
 fn intermediate_public_item_to_public_item(
